<?php
namespace Ak\Wp\Model\Entity;

use Ak\Orm\Entity\AbstractEntity;
use Ak\Wp\Model\MetaInterface;
use Doctrine\ORM\Mapping as ORM;

/**
 * Class AbstractMeta
 *
 * @package Ak\Wp\Model\Entity
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/wp-model
 */
abstract class AbstractMeta extends AbstractEntity implements MetaInterface
{
    /**
     * @ORM\Id()
     * @ORM\GeneratedValue(strategy="AUTO")
     * @ORM\Column(name="meta_id", type="bigint", options={"unsigned": true})
     */
    protected ?int $id = null;

    /**
     * @var string
     *
     * @ORM\Column(name="meta_key", type="string")
     */
    protected string $key = '';

    /**
     * @var string
     *
     * @ORM\Column(name="meta_value", type="text")
     */
    protected string $value = '';

    /**
     * Vraća ključ ovog meta-podatka.
     *
     * @return string
     */
    public function getKey(): string
    {
        return $this->key;
    }

    /**
     * Vraća vrijednost ovog meta-podatka.
     *
     * @return string
     */
    public function getValue(): string
    {
        return $this->value;
    }

    /**
     * Postavlja vrijednost ovog meta-podatka.
     *
     * @param string $value
     */
    public function setValue(string $value): void
    {
        $this->value = $value;
    }
}
