<?php
namespace Ak\Wp\Model\Entity;

use Ak\Orm\Entity\AbstractEntity;
use Ak\Orm\Entity\EntityInterface;
use Ak\Wp\Model\MetaInterface;
use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;

/**
 * Trait MetaAwareTrait
 *
 * @package Ak\Wp\Model\Entity
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/wp-model
 */
abstract class MetaAwareEntity extends AbstractEntity implements EntityInterface
{
    /**
     * @var MetaInterface[]|Collection
     */
    protected $metas;

    /**
     * MetaAwareEntity constructor.
     */
    public function __construct()
    {
        $this->metas = new ArrayCollection();
    }

    /**
     * Vraća vrijednost meta-podatka s datim ključem, $default ako meta-podatak ne postoji.
     *
     * @param string $key
     * @param mixed $default
     *
     * @return mixed
     */
    public function getMeta(string $key, $default = null)
    {
        if ($meta = $this->findMeta($key)) {
            return $meta->getValue();
        }

        return $default;
    }

    /**
     * Postavlja vrijednost meta-podatka s datim ključem.
     *
     * @param string $key
     * @param mixed $value
     */
    public function setMeta(string $key, $value): void
    {
        $meta = $this->findMeta($key);

        if (null === $meta) {
            $meta = $this->createMeta($key);
            $this->metas->add($meta);
        }

        $meta->setValue($value);
    }

    /**
     * @param string $key
     * @return MetaInterface
     */
    abstract protected function createMeta(string $key): MetaInterface;

    /**
     * @param string $key
     * @return MetaInterface|null
     */
    private function findMeta(string $key): ?MetaInterface
    {
        foreach ($this->metas as $meta) {
            if ($meta->getKey() === $key) {
                return $meta;
            }
        }

        return null;
    }
}